@@ -2,7 +2,7 @@ import optparse
 import os
 import sys
 
-from snake.tasks import env
+from snake.tasks import Task, FileTask, registry
 
 
 def load_snakefile():
@@ -17,9 +17,14 @@ def load_snakefile():
 
 
 def print_task_list(option, opt_str, value, parser):
-    print("Task list:")
-    for name in sorted(env["tasks"]):
-        print " - %s" % name
+    if registry.has_tasks_for(Task):
+        print("Task list:")
+        for name in sorted(registry.get_tasks_for(Task)):
+            print " - %s" % name
+    if registry.has_tasks_for(FileTask):
+        print("File task list:")
+        for name in sorted(registry.has_tasks_for(FileTask)):
+            print " - %s" % name
     exit()
 
 
@@ -35,8 +40,8 @@ def main():
     if not args:
         args = ['default']
     for name in args:
-        task = env["tasks"].get(name)
+        task = registry.get(name, fail_silently=True)
         if not task:
             print >> sys.stderr, "Error: task %r was not found." % name
             exit(1)
-        task()
\ No newline at end of file
+        task()
